==> camitk_4.1.2.orig.tar.gz: CamiTK-4.1.2/sdk/libraries/core/CamiTKAPI.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2018 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef CAMITK_API_H
#define CAMITK_API_H

// -----------------------------------------------------------------------
//
//                           CAMITK_API
//
// -----------------------------------------------------------------------
// The following ifdef block is the standard way of creating macros which make exporting
// from a DLL simpler. All files within this DLL are compiled with the COMPILE_CAMITK_API
// flag defined on the command line. this symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see
// CAMITK_API functions as being imported from a DLL, whereas this DLL sees symbols
// defined with this macro as being exported.
#if defined(_WIN32) // MSVC and mingw
#ifdef COMPILE_CAMITK_API
#define CAMITK_API __declspec(dllexport)
#else
#define CAMITK_API __declspec(dllimport)
#endif
#else
// for all other platforms CAMITK_API is defined to be "nothing"
#ifndef CAMITK_API
#define CAMITK_API
#endif
#endif // MSVC and mingw

// -----------------------------------------------------------------------
// It seems that MSVC does not understand exception specification
// If I understand it well, when _declspec() is used, there is a default
// nothrow attribute.
// I did not find the throw attribute. It seems that msvc is therefore ignoring the
// specification of the type of the exception.
// The compiler therefore issues a warning.
// The following line is to avoid this particular warning.
// The best would be to ask msvc not only to take the exception into account, but also
// its type. Anyway, I did not find how to do that anywhere, and I am not sure this is
// possible...
#if defined(_WIN32) && !defined(__MINGW32__) // MSVC only
#pragma warning( disable : 4290 )
#endif // MSVC only

// -----------------------------------------------------------------------
// MSVC does not have the C++ Standard rint function (it should be included in any C99 implementation)
#if defined(_WIN32) && !defined(__MINGW32__) &&(_MSC_VER < 1800)
extern double rint(double x);
#endif

// -----------------------------------------------------------------------
// -- QT stuff
#include <QList>
#include <QSet>
#include <QMap>
#include <QString>

// -----------------------------------------------------------------------
// -- Definition of some useful CamiTK container types
namespace camitk {
// -- Core stuff Classes
class Component;
class Action;

/// A list of Component
using ComponentList = QList<Component*>;

/// A set of Action
using ActionSet = QSet<Action*>;

/// A list of Action
using ActionList = QList<Action*>;
}
#endif

==> camitk_5.0.2.orig.tar.gz: CamiTK-5.0.2/sdk/libraries/core/CamiTKAPI.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef CAMITK_API_H
#define CAMITK_API_H

// -----------------------------------------------------------------------
//
//                           CAMITK_API
//
// -----------------------------------------------------------------------
// The following ifdef block is the standard way of creating macros which make exporting
// from a DLL simpler. All files within this DLL are compiled with the COMPILE_CAMITK_API
// flag defined on the command line. this symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see
// CAMITK_API functions as being imported from a DLL, whereas this DLL sees symbols
// defined with this macro as being exported.
#if defined(_WIN32) // MSVC and mingw
#ifdef COMPILE_CAMITK_API
#define CAMITK_API __declspec(dllexport)
#else
#define CAMITK_API __declspec(dllimport)
#endif
#else
// for all other platforms CAMITK_API is defined to be "nothing"
#ifndef CAMITK_API
#define CAMITK_API
#endif
#endif // MSVC and mingw

// -----------------------------------------------------------------------
// It seems that MSVC does not understand exception specification
// If I understand it well, when _declspec() is used, there is a default
// nothrow attribute.
// I did not find the throw attribute. It seems that msvc is therefore ignoring the
// specification of the type of the exception.
// The compiler therefore issues a warning.
// The following line is to avoid this particular warning.
// The best would be to ask msvc not only to take the exception into account, but also
// its type. Anyway, I did not find how to do that anywhere, and I am not sure this is
// possible...
#if defined(_WIN32) && !defined(__MINGW32__) // MSVC only
#pragma warning( disable : 4290 )
#endif // MSVC only

// -----------------------------------------------------------------------
// MSVC does not have the C++ Standard rint function (it should be included in any C99 implementation)
#if defined(_WIN32) && !defined(__MINGW32__) &&(_MSC_VER < 1800)
extern double rint(double x);
#endif

// -----------------------------------------------------------------------
// -- QT stuff
#include <QList>
#include <QSet>
#include <QMap>
#include <QString>

// -----------------------------------------------------------------------
// warning when using deprecated methods
//
// prefix each deprecated method by the CAMITK_API_DEPRECATED keyword
// CAMITK_API_DEPRECATED("Please use myNewMethod(..) instead") mymethod(...)
//
// see https://stackoverflow.com/a/295229
#if defined(__GNUC__) || defined(__clang__)
#define CAMITK_API_DEPRECATED(X) __attribute__((deprecated(X)))
#elif defined(_MSC_VER)
#define CAMITK_API_DEPRECATED(X) __declspec(deprecated(X))
#else
#pragma message("WARNING: You need to implement CAMITK_API_DEPRECATED(X) for this compiler")
#define CAMITK_API_DEPRECATED(X)
#endif

// -----------------------------------------------------------------------
// warning when using deprecated methods
//
// prefix each deprecated method by the CAMITK_API_DEPRECATED keyword
// CAMITK_API_NOT_IMPLEMENTED mymethod(...)
//
// This is silent during CamiTK Core compilation
#if !defined(COMPILE_CAMITK_API)
#if defined(__GNUC__) || defined(__clang__)
#define CAMITK_API_UNIMPLEMENTED __attribute__((deprecated("Unimplemeted method. Do not hesitate to contribute to CamiTK API!")))
#elif defined(_MSC_VER)
#define CAMITK_API_UNIMPLEMENTED __declspec(deprecated("Unimplemeted method. Do not hesitate to contribute to CamiTK API!"))
#endif // elif
#else
// inside CamiTK Core compilation
#define CAMITK_API_UNIMPLEMENTED
#if !defined(__GNUC__) && !defined(__clang__) && !defined(_MSC_VER)
#pragma message("WARNING: You need to implement CAMITK_API_UNIMPLEMENTED() for this compiler")
#endif
#endif // COMPILE_CAMITK_API

// -----------------------------------------------------------------------
// -- Definition of some useful CamiTK container types
namespace camitk {
// -- Core stuff Classes
class Component;
class Action;
class Viewer;

/// A list of Component
using ComponentList = QList<Component*>;

/// A set of Action
using ActionSet = QSet<Action*>;

/// A set of Viewer
using ViewerSet = QSet<Viewer*>;

/// A list of Action
using ActionList = QList<Action*>;

/// A list of Viewer
using ViewerList = QList<Viewer*>;
}
#endif
